@@ -112,13 +112,12 @@ class Account(object):
 
         page_iterator = paginator.paginate()
 
-        jobs_df = pd.DataFrame(columns=glue_job_df_columns)
+        data = []
         for page in page_iterator:
             for job in page["Jobs"]:
-                data = [[job["Name"], job["CreatedOn"], job["LastModifiedOn"]]]
-                df_row = pd.DataFrame(data, columns=glue_job_df_columns)
-                jobs_df = jobs_df.append(df_row)
+                data.append([job["Name"], job["CreatedOn"], job["LastModifiedOn"]])
 
+        jobs_df = pd.DataFrame(data, columns=glue_job_df_columns)
         # localize dates to remove timezone; writing to excel with timezone is not supported
         jobs_df["CreatedOn"] = jobs_df["CreatedOn"].dt.tz_localize(None)
         jobs_df["LastModifiedOn"] = jobs_df["LastModifiedOn"].dt.tz_localize(None)
@@ -138,8 +137,8 @@ class Account(object):
             "NumberOfWorkers",
             "GlueVersion",
         ]
-        job_run_df = pd.DataFrame(columns=glue_run_df_columns)
 
+        data = []
         # initialize Glue client
         client = self.session.client(AWS_GLUE_CLIENT)
         paginator = client.get_paginator("get_job_runs")
@@ -158,32 +157,28 @@ class Account(object):
                 stop_date = (
                     None if jobrun["JobRunState"] == "RUNNING" else completedon_value
                 )
-
-                row_df = pd.DataFrame(
+                data.append(
                     [
-                        [
-                            jobrun["Id"],
-                            jobrun["JobName"],
-                            jobrun["JobRunState"],
-                            jobrun["StartedOn"],
-                            stop_date,
-                            jobrun["ExecutionTime"],
-                            jobrun["MaxCapacity"],
-                            jobrun["WorkerType"]
-                            if keyexists("WorkerType", jobrun)
-                            else np.nan,
-                            jobrun["NumberOfWorkers"]
-                            if keyexists("NumberOfWorkers", jobrun)
-                            else np.nan,
-                            jobrun["GlueVersion"]
-                            if keyexists("GlueVersion", jobrun)
-                            else np.nan,
-                        ]
-                    ],
-                    columns=glue_run_df_columns,
+                        jobrun["Id"],
+                        jobrun["JobName"],
+                        jobrun["JobRunState"],
+                        jobrun["StartedOn"],
+                        stop_date,
+                        jobrun["ExecutionTime"],
+                        jobrun["MaxCapacity"],
+                        jobrun["WorkerType"]
+                        if keyexists("WorkerType", jobrun)
+                        else np.nan,
+                        jobrun["NumberOfWorkers"]
+                        if keyexists("NumberOfWorkers", jobrun)
+                        else np.nan,
+                        jobrun["GlueVersion"]
+                        if keyexists("GlueVersion", jobrun)
+                        else np.nan,
+                    ]
                 )
-                job_run_df = job_run_df.append(row_df, ignore_index=True)
 
+        job_run_df = pd.DataFrame(data, columns=glue_run_df_columns)
         job_run_df.sort_values(["StartedOn"], ascending=False, inplace=True)
         avg_duration = (
             job_run_df[job_run_df["JobRunState"] == "SUCCEEDED"]
@@ -385,25 +380,23 @@ class Account(object):
         paginator = client_lambda.get_paginator("list_functions")
         page_iterator = paginator.paginate()
 
-        functions_df = pd.DataFrame(columns=dataframe_columns)
+        data = []
 
         for page in page_iterator:
             for func in page["Functions"]:
                 row = [
-                    (
-                        func["FunctionArn"],
-                        func["FunctionName"],
-                        func["CodeSize"],
-                        func["Description"],
-                        func["Timeout"],
-                        func["MemorySize"],
-                        func["LastModified"],
-                        func["Version"],
-                    )
+                    func["FunctionArn"],
+                    func["FunctionName"],
+                    func["CodeSize"],
+                    func["Description"],
+                    func["Timeout"],
+                    func["MemorySize"],
+                    func["LastModified"],
+                    func["Version"],
                 ]
-                row_df = pd.DataFrame(row, columns=dataframe_columns)
-                functions_df = functions_df.append(row_df)
+                data.append(row)
 
+        functions_df = pd.DataFrame(columns=dataframe_columns)
         return functions_df
 
     def lambda_get_metrics_list(self, namespace="AWS/Lambda"):
@@ -419,8 +412,7 @@ class Account(object):
             "DimensionName",
             "DimensionValue",
         ]
-        metrics_df = pd.DataFrame(columns=dataframe_columns)
-
+        data = []
         for page in page_iterator:
             # print(page)
             for metric in page["Metrics"]:
@@ -433,9 +425,9 @@ class Account(object):
                             dimension["Value"],
                         )
                     ]
-                    row_df = pd.DataFrame(row, columns=dataframe_columns)
-                    metrics_df = metrics_df.append(row_df)
+                    data.append(row)
             # break
+        metrics_df = pd.DataFrame(row, columns=dataframe_columns)
         print(metrics_df.shape)
 
     def lambda_get_invocations(self, lambda_name, start_date=None, end_date=None):
@@ -469,7 +461,7 @@ class Account(object):
         )
 
         dataframe_columns = ["FunctionName", "Timestamps", "Values"]
-        metric_data_df = pd.DataFrame(columns=dataframe_columns)
+        data = []
 
         for page in page_iterator:
             for metric_data_result in page["MetricDataResults"]:
@@ -482,9 +474,11 @@ class Account(object):
                         for i in range(0, len(metric_data_result["Timestamps"]))
                     ]
                     for datapoint in datapoints:
-                        row = [(lambda_name, datapoint[0], datapoint[1])]
-                        row_df = pd.DataFrame(row, columns=dataframe_columns)
-                        metric_data_df = metric_data_df.append(row_df)
+                        row = [lambda_name, datapoint[0], datapoint[1]]
+                        data.append(row)
+
+        metric_data_df = pd.DataFrame(data, columns=dataframe_columns)
+
         logger.debug(f"Dataframe shape is {metric_data_df.shape}")
         return metric_data_df
 
@@ -494,21 +488,18 @@ class Account(object):
         paginator = client_lambda.get_paginator("list_state_machines")
         page_iterator = paginator.paginate()
 
-        stepfunctions_df = pd.DataFrame(columns=dataframe_columns)
-
+        data = []
         for page in page_iterator:
             for statemachine in page["stateMachines"]:
                 row = [
-                    (
-                        statemachine["stateMachineArn"],
-                        statemachine["name"],
-                        statemachine["type"],
-                        statemachine["creationDate"],
-                    )
+                    statemachine["stateMachineArn"],
+                    statemachine["name"],
+                    statemachine["type"],
+                    statemachine["creationDate"],
                 ]
-                row_df = pd.DataFrame(row, columns=dataframe_columns)
-                stepfunctions_df = stepfunctions_df.append(row_df)
+                data.append(row)
 
+        stepfunctions_df = pd.DataFrame(data, columns=dataframe_columns)
         return stepfunctions_df
 
     def get_available_profiles(self) -> list[str]:
@@ -536,24 +527,22 @@ class Account(object):
             ],
         )
 
-        ec2_instances_df = pd.DataFrame(columns=df_columns)
-
+        data = []
         for page in page_iterator:
             for ec2_instances in page["Reservations"]:
                 # print(ec2Instances['Instances'])
                 for instance in ec2_instances["Instances"]:
                     row = [
-                        (
-                            instance["InstanceId"],
-                            instance["InstanceType"],
-                            instance["KeyName"],
-                            instance["LaunchTime"],
-                            instance["PublicDnsName"],
-                            instance["State"]["Name"],
-                        )
+                        instance["InstanceId"],
+                        instance["InstanceType"],
+                        instance["KeyName"],
+                        instance["LaunchTime"],
+                        instance["PublicDnsName"],
+                        instance["State"]["Name"],
                     ]
-                    row_df = pd.DataFrame(row, columns=df_columns)
-                    ec2_instances_df = ec2_instances_df.append(row_df)
+                    data.append(row)
+
+        ec2_instances_df = pd.DataFrame(data, columns=df_columns)
 
         return (
             ec2_instances_df["InstanceId"].iloc[0]
